- fix wiki pages
- move wiki to pages (org or project?)
- ~~update pyamg.org~~
- ~~specific points~~
- point to code
- point to examples
- ~~analytics (google or bitdeli?)~~
- update install scripts
- C impacts: adaptive, aggregate, aggregation, rootnode, smooth, classical, split, smoothing, and of course strength
- **move pre/post smoother to solve, not setup?**
- move improve_candidates before strength?  (test before/after)
- clean up symmetry flag, maybe warn the user if flag is nonsymmetric, but
  improve_candidates or pre/postsmoother is not gauss_seidel_nr/ne
- C++ tests and nose?
